Genonets
========

This is the Python package used by the 'Genonets Server <http://ieu-genonets.uzh.ch/>' for creating and analyzing genotype networks from raw data.

The best way to get started is to work through 'genonets_exmpl_simple.py' available in the 'genonets/sample' directory. The following command can be used to view the list of
command line arguments:

'python genonets_exmpl_simple.py -h'

This directory also includes other sample files, each highlighting
different features.

The details of the analyses used and the attributes computed can be found on the 'Learn Genonets <http://ieu-genonets.uzh.ch/learn>' page.